Manual Installation
~~~~~~~~~~~~~~~~~~~
This section describes how to install the Networking-Ansible ML2 Driver
in the case that a package is not available. Networking-Ansible can be
installed from PyPI using pip.

Install components
------------------

#. Install the packages:

   .. code-block:: console

      # pip install networking-ansible
